===========
Nelder Mead
===========

An iterative Nelder Mead solver with a few extra tweaks from the standard algorithm. In high dimensions, a standard NM algorithm struggles to locate any minima. This modified NM algorithm uses an iterative approach, that while does take longer to converge, is much more effective in higher dimensional spaces than a standard approach.